@@ -29,7 +29,7 @@ sub description {
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
-    $self->usage_error("This command need one input files.") unless @{$args} == 1;
+    $self->usage_error("This command need one input file.") unless @{$args} == 1;
     for ( @{$args} ) {
         if ( !Path::Tiny::path($_)->is_file ) {
             $self->usage_error("The input file [$_] doesn't exist.");
